@@ -34,8 +34,6 @@ typedef enum {
 #define EOG_JPEG_MARKER_APP2	0xE2
 #define EOG_JPEG_MARKER_APP14	0xED
 
-#define NO_DEBUG
-
 #define IS_FINISHED(priv) (priv->exif_chunk != NULL && \
                            priv->icc_chunk  != NULL && \
                            priv->iptc_chunk != NULL && \
@@ -189,6 +187,8 @@ eog_metadata_reader_consume (EogMetadataReader *emr, guchar *buf, guint len)
 	EogMetadataReaderPrivate *priv;
  	EogJpegApp1Type app1_type;
 	int i;
+	EogMetadataReaderState next_state;
+	guchar *chunk = NULL;
 
 	g_return_if_fail (EOG_IS_METADATA_READER (emr));
 
@@ -241,8 +241,9 @@ eog_metadata_reader_consume (EogMetadataReader *emr, guchar *buf, guint len)
 			{
 				priv->state = EMR_READ_APP1;
 			} else if (priv->last_marker == EOG_JPEG_MARKER_APP2 && 
-				 priv->icc_chunk == NULL) 
+				   priv->icc_chunk == NULL && priv->size > 14)
 			{
+	 			/* Chunk has 14 bytes identification data */
 				priv->state = EMR_READ_ICC;
 			} else if (priv->last_marker == EOG_JPEG_MARKER_APP14 && 
 				priv->iptc_chunk == NULL) 
@@ -276,9 +277,6 @@ eog_metadata_reader_consume (EogMetadataReader *emr, guchar *buf, guint len)
 
 			app1_type = eog_metadata_identify_app1 ((gchar*) &buf[i], priv->size);
 			
-			EogMetadataReaderState next_state;
-			guchar *chunk = NULL;
-
 			switch (app1_type) {
 			case EJA_EXIF:
 				if (priv->exif_chunk == NULL) { 
@@ -347,9 +345,36 @@ eog_metadata_reader_consume (EogMetadataReader *emr, guchar *buf, guint len)
 				priv->bytes_read = 0;
 			}
 
-			eog_metadata_reader_get_next_block (priv, priv->icc_chunk,
-							    &i, buf, len, EMR_READ_ICC);
-			
+			eog_metadata_reader_get_next_block (priv,
+							    priv->icc_chunk,
+							    &i, buf, len,
+							    EMR_READ_ICC);
+
+			/* Test that the chunk actually contains ICC data. */
+			if (priv->state == EMR_READ && priv->icc_chunk) {
+			    	const char* icc_chunk = priv->icc_chunk;
+				gboolean valid = TRUE;
+
+				/* Chunk should begin with the 
+				 * ICC_PROFILE\0 identifier */
+				valid &= strncmp (icc_chunk,
+						  "ICC_PROFILE\0",12) == 0;
+				/* Make sure this is the first and only
+				 * ICC chunk in the file as we don't
+				 * support merging chunks yet. */
+				valid &=  *(guint16*)(icc_chunk+12) == 0x101;
+				
+				if (!valid) {
+					/* This no ICC data. Throw it away. */
+					eog_debug_message (DEBUG_IMAGE_DATA,
+					"Supposed ICC chunk didn't validate. "
+					"Ignoring.");
+					g_free (priv->icc_chunk);
+					priv->icc_chunk = NULL;
+					priv->icc_len = 0;
+				}
+			}
+
 			if (IS_FINISHED(priv))
 				priv->state = EMR_FINISHED;
 			break;
@@ -419,8 +444,8 @@ eog_metadata_reader_get_exif_data (EogMetadataReader *emr)
 
 #ifdef HAVE_EXEMPI
 
-/* skip the ID + packet */
-#define EOG_XMP_OFFSET (29 + 54)
+/* skip the signature */
+#define EOG_XMP_OFFSET (29)
 
 XmpPtr 
 eog_metadata_reader_get_xmp_data (EogMetadataReader *emr )
